function coeffs = gun
%GUN  NEP from model of a radio-frequency gun cavity.
%  COEFFS = NLEVP('gun') returns 9956-by-9956 matrices
%  K, M, W1 and W2 for the nonlinear eigenvalue problem defined by
%  T(lam)*x = [K-lam*M+i*lam^(1/2)*W1+i*(lam-108.8774^2)^(1/2)*W2]x = 0.
%  The matrices are returned in a cell array: COEFFS = {K,M,W1,W2}.
%  This problem has the properties nep, sparse.

%  References:
%  Ben-Shan Liao, Subspace projection methods for model order reduction and
%  nonlinear eigenvalue computation, Ph.D Thesis, Department of Mathematics,
%  University of California at Davis, 2007

load gun

coeffs = {K, M, W1, W2};
